|Build Status| |Coverage Status| |Stories in Ready| |PyPi|

pyramid_pages
=============

**pyramid_pages** provides a collections of pages to your Pyramid application.
This is very similar to **django.contrib.flatpages** but with a tree structure
and traversal algorithm in URL dispath.

See documentation http://pyramid-pages.readthedocs.org/en/master/

.. image:: https://raw.githubusercontent.com/ITCase/pyramid_pages/master/docs/_static/img/example.png
    :alt: pyramid_pages - example of website pages tree
    :width: 800px
    :align: center

Support and Development
=======================

To report bugs, use the `issue tracker <https://github.com/ITCase/pyramid_pages/issues>`_
or `waffle board <https://waffle.io/ITCase/pyramid_pages>`_.

We welcome any contribution: suggestions, ideas, commits with new futures, bug
fixes, refactoring, docs, tests, translations etc

If you have question, contact me sacrud@uralbash.ru or IRC channel #sacrud

License
=======

The project is licensed under the MIT license.

.. |Build Status| image:: https://travis-ci.org/ITCase/pyramid_pages.svg?branch=master
   :target: https://travis-ci.org/ITCase/pyramid_pages
.. |Coverage Status| image:: https://coveralls.io/repos/ITCase/pyramid_pages/badge.png
   :target: https://coveralls.io/r/ITCase/pyramid_pages
.. |Stories in Ready| image:: https://badge.waffle.io/itcase/pyramid_pages.png?label=in%20progress&title=In%20Progress
   :target: https://waffle.io/itcase/pyramid_pages
.. |PyPI| image:: http://img.shields.io/pypi/dm/pyramid_pages.svg
   :target: https://pypi.python.org/pypi/pyramid_pages/
